<?php

namespace WPAI;

if (!defined('ABSPATH')) {
    die('Invalid request.');
}

class WPAI_Campaign_Manager {

    public $campaigns;
    protected $next_id;

    public function __construct() {
        $this->load();
        $this->next_id = 1;
        foreach ($this->campaigns as $campaign) {
            if ($campaign['id'] ?? 0 > $this->next_id) {
                $this->next_id = ($campaign['id'] ?? 0) + 1;
            }
        }
    }

    public function save() {
        update_option(WPAI_CAMPAIGNS, $this->campaigns);
    }

    public function load() {
        $this->campaigns = get_option(WPAI_CAMPAIGNS);
        if ($this->campaigns && count($this->campaigns)) {
            for ($i = 0; $i < count($this->campaigns); $i++) {
                $campaign = $this->new_compaign();
                foreach ($this->campaigns[$i] as $key => $value) {
                    $campaign[$key] = $value;
                }
                $this->campaigns[$i] = $campaign;
            }
        } else {
            $this->campaigns = [];
        }
    }

    public function new_compaign() {
        $campaign = [
            'id' => $this->next_id(),
            'name' => 'ad campaign (please give me a name)',
            'ad_code' => '',
            'ad_head' => '',
            'php_exec' => '',
            'behavior' => 'always-display',
            'max_ad_limit' => 1,
            'position' => 'before-content',
            'bp_pos' => 1,
            'ap_pos' => 1,
            'bi_pos' => 1,
            'ai_pos' => 1,
            'bh_pos' => 1,
            'ah_pos' => 1,
            'bh_tag' => 'h2',
            'ah_tag' => 'h2',
            'bfp_pos' => 1,
            'start_html_element' => '',
            'end_html_element' => '',
            'use_regex' => '',
            'cats' => '',
            'cat_rule' => 'any',
            'tags' => '',
            'tag_rule' => 'any',
            'keywords' => '',
            'keyword_rule' => 'any',
            'target_content' => 'on',
            'target_excerpt' => 'on',
            'target_title' => 'on',
            'rotate' => 'on',
            'post_ids' => '',
            'post_ids_rule' => 'show',
            'devices_rule' => 'show',
            'device_computer' => 'on',
            'device_tablet' => 'on',
            'device_phone' => 'on',
            'country_codes' => '',
            'country_code_rule' => 'show',
            'city_codes' => '',
            'city_code_rule' => 'show',
            'browser_lang_rule' => 'show',
            'browser_langs' => '',
            'show_in_posts' => 'on',
            'show_in_pages' => 'on',
            'show_at_homepage' => 'on',
            'show_in_categoris' => 'on',
            'show_in_tags' => 'on',
            'show_in_archives' => 'on',
            'show_in_search_results' => 'on',
            'show_in_excerpts' => 'on',
            'total_impressions' => 0,
            'show_on_monday' => 'on',
            'show_on_tuesday' => 'on',
            'show_on_wednesday' => 'on',
            'show_on_thursday' => 'on',
            'show_on_friday' => 'on',
            'show_on_saturday' => 'on',
            'show_on_sunday' => 'on',
            'time_ranges' => '',
        ];
        return $campaign;
    }

    public function delete_compaign($index) {
        if (isset($this->campaigns[$index])) {
            unset($this->campaigns[$index]);
            $this->campaigns = array_values($this->campaigns);
            $this->save();
        }
    }

    public function move_compaign_up($index) {
        if ($index > 0) {
            $tmp = $this->campaigns[$index - 1];
            $this->campaigns[$index - 1] = $this->campaigns[$index];
            $this->campaigns[$index] = $tmp;
            $this->save();
        }
    }

    public function move_compaign_down($index) {
        if ($index < count($this->campaigns) - 1) {
            $tmp = $this->campaigns[$index + 1];
            $this->campaigns[$index + 1] = $this->campaigns[$index];
            $this->campaigns[$index] = $tmp;
            $this->save();
        }
    }

    public function next_id() {
        $id = 0;
        foreach ($this->campaigns as $campaign) {
            $id = max($id, $campaign['id']);
        }
        return $id + 1;
    }

    public function get_index_by_id($id) {
        for ($i = 0; $i < count($this->campaigns); $i++) {
            if ($this->campaigns[$i]['id'] === $id) {
                return $i;
            }
        }
        return false;
    }

    public function inc_total_impressions($id) {
        $this->campaigns[$this->get_index_by_id($id)]['total_impressions']++;
        $this->save();
    }

    public function display_campaigns() {
        echo '<h2 style="margin-bottom: 16pt;">Ad campaigns</h2>';
        echo '<div class="wrap">';
        echo '<form id="campaigns" method="post" action="?page=wpai&new-campaign">';
        echo '<table class="widefat" style="margin-top: .5em" width="100%">';
        echo '<tr style="background: #f0f0f0;">';
        echo '<th style="width:5%;">ID</th>';
        echo '<th style="width:70%;">Campaign Name</th>';
        echo '<th style="width:auto;"><nobr>Total impressions</nobr></th>';
        echo '<th style="text-align:left; width:auto;">Position</th>';
        echo '<th style="width:auto;"></th>';
        echo '<th style="width:auto"></th>';
        echo '<th style="width:auto"></th>';
        echo '</tr>';
        foreach ($this->campaigns as $key => $campaign) {
            if ($campaign['position'] === 'manual') {
                echo '<tr class="alternate">';
            } else {
                echo '<tr>';
            }
            echo '<td><nobr>';
            echo $campaign['id'];
            echo '</nobr></td>';
            echo '<td>';
            echo htmlentities(stripslashes($campaign['name']));
            echo '</td>';
            echo '<td>';
            echo stripslashes($campaign['total_impressions']);
            echo '</td>';
            echo '<td style="text-align:left;width:auto;">';
            echo '<nobr>' . str_replace('-', ' ', $campaign['position']) . '</nobr>';
            echo '</td>';
            echo '<td>';
            echo '<nobr>[<a href="' . wp_nonce_url('?page=wpai&edit-campaign=' . $key, 'wpai-campaign-edit') . '"> Edit </a>]</nobr>';
            echo '</td>';
            echo '<td>';
            echo '<nobr>[<a style="color:red;" href="' . wp_nonce_url('?page=wpai&delete-campaign=' . $key, 'wpai-campaign-delete') . '" onClick="return confirm(\'Do you really want to delete this ad campaign?\')"> Delete </a>]</nobr>';
            echo '</td>';
            echo '<td style="text-align:right;width:auto;">';
            echo '<nobr>';
            if ($key === 0) {
                echo '<span style="filter: opacity(50%);">🔼</span>';
            } else {
                echo '<a href="' . wp_nonce_url('?page=wpai&up=' . $key, 'wpai-campaign-up') . '">🔼</a>';
            }
            if ($key === count($this->campaigns) - 1) {
                echo '<span style="filter: opacity(50%);">🔽</span>';
            } else {
                echo '<a href="' . wp_nonce_url('?page=wpai&down=' . $key, 'wpai-campaign-down') . '">🔽</a>';
            }
            echo '</nobr>';
            echo '</td>';
            echo '</tr>';
        }
        echo '</table>';
        echo '<br /><input class="button-primary" name="new-campaign" value="New ad campaign" type="submit">';
        wp_nonce_field('wpai');
        echo '</form>';
        echo '</div>';
    }

    public function show_pro_campaign_options($campaign) {
        // available in PRO version
        return;
    }

    public function campaign_options_panel($index = null) {
        echo '<div class="wrap">';
        if ($index !== null) {
            $campaign = $this->campaigns[$index];
            echo '<form id="campaign_options" method="post" action="?page=wpai&campaign=' . $index . '">';
            echo '<input type="hidden" name="index" value="' . $index . '">';
        } else {
            $campaign = $this->new_compaign();
            echo '<form id="campaign_options" method="post" action="?page=wpai">';
        }
        echo '<table style="width:90%" class="form-table">';
        echo '<tr>';
        echo '<th>Campaign name</th>';
        echo '<td>';
        echo '<input type="text" name="name" style="width:100%" value="' . stripslashes($campaign['name']) . '">';
        echo '<p class="description">Give some informative name or a short description to this ad campaign.</p>';
        echo '</td>';
        echo '</tr>';
        echo '<tr>';

        echo '<th>Ad code</th>';
        echo '<td>';
        echo '<textarea id="ad_code" name="ad_code" wrap="on" style="width:100%;background-color:white">' . stripslashes($campaign['ad_code']) . '</textarea>';
        echo '<p class="description">You can specify more than one ad here. Just use the <code>&lt;!--more--&gt;</code> separator to divide your ads. So you can have a few rotaing ads in the same spot.</p>';
        echo '</td>';
        echo '</tr>';

        echo '<th>Ad head</th>';
        echo '<td>';
        echo '<textarea id="ad_head" name="ad_head" wrap="on" style="width:100%;background-color:white">' . stripslashes($campaign['ad_head']) . '</textarea>';
        echo '<p class="description">The contents of this field will be inserted into the <code>&lt;head&gt;</code> section of a webpage.</p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Ad behavior</th>';
        echo '<td>';
        echo '<select id="behavior_box" name="behavior" style="margin-top:-4px;" onchange="wpaiDisplayMaxAdsField();">';
        echo '<option ' . (($campaign['behavior'] === 'always-display') ? 'selected ' : '') . 'value="always-display">Always display</option>';
        echo '<option ' . (($campaign['behavior'] === 'skip-on-max-in-spot') ? 'selected ' : '') . 'value="skip-on-max-in-spot">Skip if the max number of ads in this spot is reached</option>';
        echo '<option ' . (($campaign['behavior'] === 'skip-on-max-total') ? 'selected ' : '') . 'value="skip-on-max-total">Skip if the max number of all displayed ads on the page is reached</option>';
        echo '</select>';
        // Skip for max ads number
        echo '<div id="max_ad_limit" style="display: none;"><p><input type="text" name="max_ad_limit" size="2" value="' . abs(intval(stripslashes($campaign['max_ad_limit']))) . '">
              - <span style="color: #646970;">specify the max number of posts for the selected behavior rule.</span></p></div>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Position</th>';
        echo '<td>';
        echo '<select id="position_box" name="position" style="margin-top:-4px;" onchange="wpaiDisplaySectionField();">';
        echo '<option ' . (($campaign['position'] === 'manual') ? 'selected ' : '') . 'value="manual">Manual</option>';
        echo '<option ' . (($campaign['position'] === 'before-the-loop') ? 'selected ' : '') . 'value="before-the-loop">Before the Loop</option>';
        echo '<option ' . (($campaign['position'] === 'after-the-loop') ? 'selected ' : '') . 'value="after-the-loop">After the Loop</option>';
        echo '<option ' . (($campaign['position'] === 'before-content') ? 'selected ' : '') . 'value="before-content">Before content</option>';
        echo '<option ' . (($campaign['position'] === 'after-content') ? 'selected ' : '') . 'value="after-content">After content</option>';
        echo '<option ' . (($campaign['position'] === 'before-paragraph') ? 'selected ' : '') . 'value="before-paragraph">Before paragraph</option>';
        echo '<option ' . (($campaign['position'] === 'after-paragraph') ? 'selected ' : '') . 'value="after-paragraph">After paragraph</option>';
        echo '<option ' . (($campaign['position'] === 'before-heading') ? 'selected ' : '') . 'value="before-heading">Before heading</option>';
        echo '<option ' . (($campaign['position'] === 'after-heading') ? 'selected ' : '') . 'value="after-heading">After heading</option>';
        echo '<option ' . (($campaign['position'] === 'before-image') ? 'selected ' : '') . 'value="before-image">Before image</option>';
        echo '<option ' . (($campaign['position'] === 'after-image') ? 'selected ' : '') . 'value="after-image">After image</option>';
        echo '<option ' . (($campaign['position'] === 'before-post') ? 'selected ' : '') . 'value="before-post">Before post</option>';
        echo '<option ' . (($campaign['position'] === 'site-footer') ? 'selected ' : '') . 'value="site-footer">Site footer</option>';
        echo '<option ' . (($campaign['position'] === 'comment-form-before') ? 'selected ' : '') . 'value="comment-form-before">Before comment form</option>';
        echo '<option ' . (($campaign['position'] === 'comment-form-after') ? 'selected ' : '') . 'value="comment-form-after">After comment form</option>';
        echo '<option ' . (($campaign['position'] === 'comment-form-top') ? 'selected ' : '') . 'value="comment-form-top">Comment form top</option>';
        echo '<option ' . (($campaign['position'] === 'comment-form-before-fields') ? 'selected ' : '') . 'value="comment-form-before-fields">Comment form before fields</option>';
        echo '<option ' . (($campaign['position'] === 'comment-form-after-fields') ? 'selected ' : '') . 'value="comment-form-after-fields">Comment form after fields</option>';
        echo '<option ' . (($campaign['position'] === 'widget') ? 'selected ' : '') . 'value="widget">WP Ad Inserter Widget</option>';
        echo '<option ' . (($campaign['position'] === 'between-html') ? 'selected ' : '') . 'value="between-html">Between HTML elements</option>';
        echo '</select>';
        // Manual desc
        echo '<div id="manual" style="display:none;"><p class="description">The ad won\'t be shown except if it manually included as a shortcode into a post or into a text widget. It can also
            be included as a PHP code into a WordPress theme.</p></div>';
        // Before the Loop desc
        echo '<div id="before_loop" style="display:none;"><p class="description">The ad will be shown before the WordPress Loop. The Loop is a PHP code block that displays WordPress posts. The loop is used in
            WordPress themes to display a list of posts in a webpage. Thus the ad will be placed before all posts on the index page, archives page, tag page category page page or search results page.</p></div>';
        // After the Loop desc
        echo '<div id="after_loop" style="display:none;"><p class="description">The ad will be shown after the WordPress Loop. The Loop is a PHP code block that displays WordPress posts. The loop is used in
            WordPress themes to display a list of posts in a webpage. Thus the ad will be placed after all posts on the index page, archives page, tag page category page page or search results page.</p></div>';
        // Before content desc
        echo '<div id="before_content" style="display:none;"><p class="description">Places the ad before of the post or page content.</p></div>';
        // After content desc
        echo '<div id="after_content" style="display:none;"><p class="description">Places the ad after of the post or page content.</p></div>';
        // Before paragraph desc
        echo '<div id="bp_pos" style="display:none;"> #<input type="text" name="bp_pos" size="1" value="' . stripslashes($campaign['bp_pos']) . '"><p class="description">Set a paragraph number before which
            the ad should be inserted. If the number is negative, the paragraphs will be counted from the end of the post. When the number is equal to zero (0), a random paragraph will be used.</code></p></div>';
        // After paragraph desc
        echo '<div id="ap_pos" style="display:none;"> #<input type="text" name="ap_pos" size="1" value="' . stripslashes($campaign['ap_pos']) . '"><p class="description">Set a paragraph number after which
            the ad should be inserted. If the number is negative, the paragraphs will be counted from the end of the post. When the number is equal to zero (0), a random paragraph will be used.</code></p></div>';
        // Before heading desc
        echo '<div id="bh_pos" style="display:none;">
        <select name="bh_tag" style="margin-top:-4px;">
        <option ' . (($campaign['bh_tag'] === 'h1') ? 'selected ' : '') . 'value="h1">&lt;h1&gt;</option>
        <option ' . (($campaign['bh_tag'] === 'h2') ? 'selected ' : '') . 'value="h2">&lt;h2&gt;</option>
        <option ' . (($campaign['bh_tag'] === 'h3') ? 'selected ' : '') . 'value="h3">&lt;h3&gt;</option>
        <option ' . (($campaign['bh_tag'] === 'h4') ? 'selected ' : '') . 'value="h4">&lt;h4&gt;</option>
        <option ' . (($campaign['bh_tag'] === 'h5') ? 'selected ' : '') . 'value="h5">&lt;h5&gt;</option>
        <option ' . (($campaign['bh_tag'] === 'h6') ? 'selected ' : '') . 'value="h6">&lt;h6&gt;</option>    
        </select>
        #<input type="text" name="bh_pos" size="1" value="' . stripslashes($campaign['bh_pos']) . '"><p class="description">Select a heading tag and set the section number after which the ad should be inserted. 
            If the number is negative, the headings will be counted from the end of the post. When the number is equal to zero (0), a random heading will be used.</code></p></div>';
        // After heading desc
        echo '<div id="ah_pos" style="display:none;">
        <select name="ah_tag" style="margin-top:-4px;">
        <option ' . (($campaign['ah_tag'] === 'h1') ? 'selected ' : '') . 'value="h1">&lt;h1&gt;</option>
        <option ' . (($campaign['ah_tag'] === 'h2') ? 'selected ' : '') . 'value="h2">&lt;h2&gt;</option>
        <option ' . (($campaign['ah_tag'] === 'h3') ? 'selected ' : '') . 'value="h3">&lt;h3&gt;</option>
        <option ' . (($campaign['ah_tag'] === 'h4') ? 'selected ' : '') . 'value="h4">&lt;h4&gt;</option>
        <option ' . (($campaign['ah_tag'] === 'h5') ? 'selected ' : '') . 'value="h5">&lt;h5&gt;</option>
        <option ' . (($campaign['ah_tag'] === 'h6') ? 'selected ' : '') . 'value="h6">&lt;h6&gt;</option>    
        </select>
        #<input type="text" name="ah_pos" size="1" value="' . stripslashes($campaign['ah_pos']) . '"><p class="description">Select a heading tag and set the section number after which the ad should be inserted.
            If the number is negative, the headings will be counted from the end of the post. When the number is equal to zero (0), a random heading will be used.</code></p></div>';
        // Before image desc
        echo '<div id="bi_pos" style="display:none;"> #<input type="text" name="bi_pos" size="1" value="' . stripslashes($campaign['bi_pos']) . '"><p class="description">Set an image number before which the ad
            should be inserted. If the number is negative, the images will be counted from the end of the post. When the number is equal to zero (0), a random image will be used.</code></p></div>';
        // After image desc
        echo '<div id="ai_pos" style="display:none;"> #<input type="text" name="ai_pos" size="1" value="' . stripslashes($campaign['ai_pos']) . '"> <p class="description">Set an image number after which the ad
            should be inserted. If the number is negative, the images will be counted from the end of the post. When the number is equal to zero (0), a random image will be used.</code></p></div>';
        // Before post desc
        echo '<div id="bfp_pos" style="display:none;"> #<input type="text" name="bfp_pos" size="1" value="' . stripslashes($campaign['bfp_pos']) . '"><p class="description">Set a post number before which the ad
            should be inserted on the site homepage, search results page, category page or archive page. Use this mode to insert ads between posts in the Loop.</code></p></div>';
        // Site footer desc
        echo '<div id="site_footer" style="display:none;"><p class="description">Places the ad into the site footer.</code></p></div>';
        // WP Ad Inserter widget desc
        echo '<div id="wpai_widget" style="display:none;"><p class="description">The ad will be shown in the WP Ad Inserter widget.</p></div>';
        // Between HTML elements desc
        echo '<div id="between_html_block" style="display:none;"> - <span style="color: #646970;">insert the ad between two HTML elements.</span>
            <p>Start HTML element<br /><input type="text" name="start_html_element" style="width:100%;" value="' . stripslashes($campaign['start_html_element']) . '"></p>
            <p>End HTML element<br /><input type="text" name="end_html_element" style="width:100%;" value="' . stripslashes($campaign['end_html_element']) . '"></p>
            <p>Use <a href="https://en.wikipedia.org/wiki/Regular_expression" target="_blank">regular expressions</a> <input name="use_regex" type="checkbox" ' . ((($campaign['use_regex']) === 'on') ? 'checked ' : '') . '"></p>';
        // Before comment form
        echo '<div id="comment_form_before" style="display:none;"><p class="description">Places an ad above the comment form.</p></div>';
        // After comment form
        echo '<div id="comment_form_after" style="display:none;"><p class="description">Places an ad below the comment form./p></div>';
        // Comment form top
        echo '<div id="comment_form_top" style="display:none;"><p class="description">Places an ad before the comment form.</p></div>';
        // Comment form before fields
        echo '<div id="comment_form_before_fields" style="display:none;"><p class="description">Places an ad before the data fields on the comment form.</p></div>';
        // Comment form after fields
        echo '<div id="comment_form_after_fields" style="display:none;"><p class="description">Places an ad after the data fields on the comment form.</p></div>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Display in</th>';
        echo '<td>';
        echo '<p><span class="wpai-field">posts <input name="show_in_posts" type="checkbox" ' . ((($campaign['show_in_posts']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">pages <input name="show_in_pages" type="checkbox" ' . ((($campaign['show_in_pages']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">excerpts <input name="show_in_excerpts" type="checkbox" ' . ((($campaign['show_in_excerpts']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">hompage <input name="show_at_homepage" type="checkbox" ' . ((($campaign['show_at_homepage']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">categories <input name="show_in_categoris" type="checkbox" ' . ((($campaign['show_in_categoris']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">tags <input name="show_in_tags" type="checkbox" ' . ((($campaign['show_in_tags']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">archives <input name="show_in_archives" type="checkbox" ' . ((($campaign['show_in_archives']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">search results <input name="show_in_search_results" type="checkbox" ' . ((($campaign['show_in_search_results']) === 'on') ? 'checked ' : '') . '"></span></p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Shortcode</th>';
        echo '<td>';
        echo '<code>[wpadinserter id="' . $campaign['id'] . '"]</code>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>PHP code for theme</th>';
        echo '<td>';
        echo '<code>&lt;?php echo do_shortcode(\'[wpadinserter id="' . $campaign['id'] . '"]\'); ?&gt;</code>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Execute PHP</th>';
        echo '<td>';
        echo '<input name="php_exec" type="checkbox" ' . ((($campaign['php_exec']) === 'on') ? 'checked ' : '') . '"><span style="color: #646970;">- enable this ouption to execute PHP code inside your ads.</span>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Rotate</th>';
        echo '<td>';
        echo '<input name="rotate" type="checkbox" ' . ((($campaign['rotate']) === 'on') ? 'checked ' : '') . '"><span style="color: #646970;">- when enabled, the ads divided by the <code>&lt;!--more--&gt;</code>
            separator will be rotated every time a webpage is displayed. Otherwise, every post will be shown with the same ad.</span>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Post IDs</th>';
        echo '<td>';
        echo '<select name="post_ids_rule">';
        echo '<option ' . (($campaign['post_ids_rule'] === 'show') ? 'selected ' : '') . 'value="show">✔️ Display on</option>';
        echo '<option ' . (($campaign['post_ids_rule'] === 'hide') ? 'selected ' : '') . 'value="hide">🚧 Hide on</option>';
        echo '</select><span style="color: #646970;"> - select a display rule and specify a comma-separated list of post and page IDs:</span>';
        echo '<p><input type="text" name="post_ids" style="width:100%" value="' . stripslashes($campaign['post_ids']) . '"></p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Categories</th>';
        echo '<td>';
        echo '<select name="cat_rule">';
        echo '<option ' . (($campaign['cat_rule'] === 'any') ? 'selected ' : '') . 'value="any">✔️ Must contain any of these</option>';
        echo '<option ' . (($campaign['cat_rule'] === 'none') ? 'selected ' : '') . 'value="none">🚧 Must contain none of these</option>';
        echo '<option ' . (($campaign['cat_rule'] === 'all') ? 'selected ' : '') . 'value="all">💯 Must contain all of these</option>';
        echo '</select><span style="color: #646970;"> - select a display rule and specify a comma-separated list of post categories (case-insensitive):</span>';
        echo '<p><input type="text" name="cats" style="width:100%" value="' . stripslashes($campaign['cats']) . '"></p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Tags</th>';
        echo '<td>';
        echo '<select name="tag_rule">';
        echo '<option ' . (($campaign['tag_rule'] === 'any') ? 'selected ' : '') . 'value="any">✔️ Must contain any of these</option>';
        echo '<option ' . (($campaign['tag_rule'] === 'none') ? 'selected ' : '') . 'value="none">🚧 Must contain none of these</option>';
        echo '<option ' . (($campaign['tag_rule'] === 'all') ? 'selected ' : '') . 'value="all">💯 Must contain all of these</option>';
        echo '</select><span style="color: #646970;"970;> - select a display rule and specify a comma-separated list of post tags (case-insensitive):</span>';
        echo '<p><input type="text" name="tags" style="width:100%" value="' . stripslashes($campaign['tags']) . '"></p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Keywords (phrases)</th>';
        echo '<td>';
        echo '<select name="keyword_rule">';
        echo '<option ' . (($campaign['keyword_rule'] === 'any') ? 'selected ' : '') . 'value="any">✔️ Must contain any of these</option>';
        echo '<option ' . (($campaign['keyword_rule'] === 'none') ? 'selected ' : '') . 'value="none">🚧 Must contain none of these</option>';
        echo '<option ' . (($campaign['keyword_rule'] === 'all') ? 'selected ' : '') . 'value="all">💯 Must contain all of these</option>';
        echo '</select><span style="color: #646970;"> - select a display rule and specify a comma-separated list of keywords (case-insensitive, full words):</span>';
        echo '<p><input type="text" name="keywords" style="width:100%;" value="' . stripslashes($campaign['keywords']) . '"></p>';
        echo '<p>Check for keywords in <span class="wpai-field">content <input name="target_content" type="checkbox" ' . ((($campaign['target_content']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">excerpt <input name="target_excerpt" type="checkbox" ' . ((($campaign['target_excerpt']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">title <input name="target_title" type="checkbox" ' . ((($campaign['target_title']) === 'on') ? 'checked ' : '') . '"></span></p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>Devices</th>';
        echo '<td>';
        echo '<select name="devices_rule">';
        echo '<option ' . (($campaign['devices_rule'] === 'show') ? 'selected ' : '') . 'value="show">✔️ Display on</option>';
        echo '<option ' . (($campaign['devices_rule'] === 'hide') ? 'selected ' : '') . 'value="hide">🚧 Hide on</option>';
        echo '</select><span style="color: #646970;"> - select visitor decive type(s).</span>';
        echo '<p><span class="wpai-field">computers <input name="device_computer" type="checkbox" ' . ((($campaign['device_computer']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">tablets <input name="device_tablet" type="checkbox" ' . ((($campaign['device_tablet']) === 'on') ? 'checked ' : '') . '"></span>
             <span class="wpai-field">phones <input name="device_phone" type="checkbox" ' . ((($campaign['device_phone']) === 'on') ? 'checked ' : '') . '"></span></p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>System language codes</th>';
        echo '<td>';
        echo '<select name="browser_lang_rule">';
        echo '<option ' . (($campaign['browser_lang_rule'] === 'show') ? 'selected ' : '') . 'value="show">✔️ Display for</option>';
        echo '<option ' . (($campaign['browser_lang_rule'] === 'hide') ? 'selected ' : '') . 'value="hide">🚧 Hide for</option>';
        echo '</select><span style="color: #646970;"> - select a display rule and specify a comma-separated list of system language codes (en-US, ru-RU, be, zh-CN etc) (case-insensitive):</span>';
        echo '<p><input type="text" name="browser_langs" style="width:100%" value="' . stripslashes($campaign['browser_langs']) . '"></p>';
        echo '<p class="description">Check the <a href="https://www.wpadinserter.com/campaign-settings/#system-language-codes" target="_blank">documentation</a> for the system language code list.</p>';
        echo '</td>';
        echo '</tr>';

        echo '<tr>';
        echo '<th>ISO country codes</th>';
        echo '<td>';
        echo '<select name="country_code_rule">';
        echo '<option ' . (($campaign['country_code_rule'] === 'show') ? 'selected ' : '') . 'value="show">✔️ Display for</option>';
        echo '<option ' . (($campaign['country_code_rule'] === 'hide') ? 'selected ' : '') . 'value="hide">🚧 Hide for</option>';
        echo '</select><span style="color: #646970;"> - select a display rule and specify a comma-separated list of country ISO codes (US, DE, UK, RU, FR, IT etc) (case-insensitive):</span>';
        echo '<p><input type="text" name="country_codes" style="width:100%" value="' . stripslashes($campaign['country_codes']) . '"></p>';
        echo '<p class="description">Check the <a href="https://www.wpadinserter.com/campaign-settings/#iso-country-codes" target="_blank">documentation</a> for the country ISO code list.</p>';
        echo '</td>';
        echo '</tr>';

        echo '</table>';

        $this->show_pro_campaign_options($campaign);

        if ($index !== null) {
            echo '<input class = "button-primary" style = "margin: 2pt;" name="modify-campaign" value=" Save " type="submit">';
        } else {
            echo '<input class = "button-primary" style = "margin: 2pt;" name="modify-campaign" value=" Add " type="submit">';
        }
        echo '<input class = "button" style = "margin:2pt;" name="cancel" value=" Back " type="submit">';
        wp_nonce_field('wpai');
        echo '</form>';
        echo '</div>';
        echo '<script>
            wpaiDisplayMaxAdsField();
            wpaiDisplaySectionField();
            
            var editor = CodeMirror.fromTextArea(document.getElementById("ad_code"), {
            lineWrapping: true,
            lineNumbers: true,
            spellcheck: false,
            matchBrackets: true,
            mode: "application/x-httpd-php",
            indentUnit: 8,
            indentWithTabs: true,
            enterMode: "keep",
            tabMode: "shift"
            });
            
        var editor = CodeMirror.fromTextArea(document.getElementById("ad_head"), {
            lineWrapping: true,
            lineNumbers: true,
            spellcheck: false,
            matchBrackets: true,
            mode: "application/x-httpd-php",
            indentUnit: 8,
            indentWithTabs: true,
            enterMode: "keep",
            tabMode: "shift"
            });
         editor.setSize("100%", "20em");
        </script>';
    }

    public function edit_campaign_menu($index) {
        if (isset($this->campaigns[$index])) {
            echo '<h2>WP Ad Inserter - Edit campaign';
            $this->campaign_options_panel($index);
        } else {
            echo '<form method="post" action="?page=wpai">';
            echo '<div class="notice notice-info" style="padding: 20pt; 0;">';
            echo 'Error: campaign does not exist.';
            echo '</div>';
            echo '<input class="button" style="margin:2pt;" name="cancel" value=" Back " type="submit">';
            echo '</form>';
        }
    }

    public function new_campaign_menu() {
        echo '<h2>WP Ad Inserter - Add new campaign</h2>';
        $this->campaign_options_panel(null);
    }

}

?>