<?php

namespace WPAI;

if (!defined('ABSPATH')) {
    die('Invalid request.');
}

define('WPAI_MIXMIND_GEOIP2_COUNTRY_BASE_URL', 'https://cdn.jsdelivr.net/npm/geolite2-country@1.0.2/GeoLite2-Country.mmdb.gz');

require_once plugin_dir_path(__FILE__) . 'class-wpai-campaign-manager.php';

if (WPAI_PRO) {
    require_once plugin_dir_path(__FILE__) . 'class-wpai-campaign-manager-pro.php';
}

class WPAI {

    public $options;
    protected $cm;
    protected $plugin_dir_path;
    protected $plugin_dir_url;
    protected $maxmind_geoip2;
    protected $aimd;
    protected $spots;

    public function __construct($plugin_dir_url, $plugin_dir_path) {
        $this->plugin_dir_path = $plugin_dir_path;
        $this->plugin_dir_url = $plugin_dir_url;

        $this->options = get_option(WPAI_OPTIONS);
        if (!is_array($this->options)) {
            $this->options = [];
            $this->options['delete_on_uninstall'] = $this->options['delete_on_uninstall'] ?? '';
            $this->options['geoip_auto_update'] = $this->options['geoip_auto_update'] ?? '';
            $this->options['geoip_last_update'] = $this->options['geoip_last_update'] ?? 0;
        }

        $geoip2_base_file = $this->get_geoip_base();
        if (file_exists($geoip2_base_file)) {
            try {
                $this->maxmind_geoip2 = new \MaxMind\Db\Reader($geoip2_base_file);
            } catch (\Throwable $e) {
                update_option(WPMI_MESSAGE, $e->getMessage());
            }
        } else {
            update_option(WPMI_MESSAGE, 'The file "' . $geoip2_base_file . '" does not exist or is not readable.');
        }

        if (WPAI_PRO) {
            $this->cm = new WPAI_Campaign_Manager_Pro();
        } else {
            $this->cm = new WPAI_Campaign_Manager();
        }
        add_action('admin_menu', array($this, 'settings_menu'));

        $this->spots = new WPAI_Ad_Spots();
    }

    public function get_campaigns() {
        return $this->cm->campaigns;
    }

    public function wpai_menu() {
        if (isset($_POST['modify-campaign']) && check_admin_referer('wpai')) {
            if (isset($_POST['index'])) {
                if (isset($this->cm->campaigns[intval($_POST['index'])])) {
                    $campaign = $this->cm->campaigns[intval($_POST['index'])];
                } else {
                    echo '<div class="notice notice-info" style="padding: 20pt; 0;">';
                    echo 'Something went wrong. The settings hava not been saved.';
                    echo '</div>';
                }
            } else {
                $campaign = $this->cm->new_compaign();
            }

            $campaign['name'] = trim($_POST['name']);
            $campaign['php_exec'] = $_POST['php_exec'] ?? '';
            $campaign['ad_code'] = $_POST['ad_code'];
            $campaign['ad_head'] = $_POST['ad_head'];
            $campaign['behavior'] = $_POST['behavior'];
            $campaign['max_ad_limit'] = intval($_POST['max_ad_limit']);
            $campaign['position'] = $_POST['position'];
            $campaign['bp_pos'] = intval($_POST['bp_pos']);
            $campaign['ap_pos'] = intval($_POST['ap_pos']);
            $campaign['bi_pos'] = intval($_POST['bi_pos']);
            $campaign['ai_pos'] = intval($_POST['ai_pos']);
            $campaign['bh_pos'] = intval($_POST['bh_pos']);
            $campaign['ah_pos'] = intval($_POST['ah_pos']);
            $campaign['bfp_pos'] = intval($_POST['bfp_pos']);
            $campaign['bh_tag'] = $_POST['bh_tag'];
            $campaign['ah_tag'] = $_POST['ah_tag'];
            $campaign['cats'] = trim($_POST['cats']);
            $campaign['cat_rule'] = $_POST['cat_rule'];
            $campaign['tags'] = trim($_POST['tags']);
            $campaign['tag_rule'] = $_POST['tag_rule'];
            $campaign['keywords'] = trim($_POST['keywords']);
            $campaign['keyword_rule'] = $_POST['keyword_rule'];
            $campaign['target_content'] = $_POST['target_content'] ?? '';
            $campaign['target_excerpt'] = $_POST['target_excerpt'] ?? '';
            $campaign['target_title'] = $_POST['target_title'] ?? '';
            $campaign['rotate'] = $_POST['rotate'] ?? '';
            $campaign['devices_rule'] = $_POST['devices_rule'];
            $campaign['device_computer'] = $_POST['device_computer'] ?? '';
            $campaign['device_tablet'] = $_POST['device_tablet'] ?? '';
            $campaign['device_phone'] = $_POST['device_phone'] ?? '';
            $campaign['country_codes'] = trim($_POST['country_codes']);
            $campaign['country_code_rule'] = $_POST['country_code_rule'];
            $campaign['post_ids'] = trim($_POST['post_ids']);
            $campaign['post_ids_rule'] = $_POST['post_ids_rule'];
            $campaign['browser_langs'] = trim($_POST['browser_langs']);
            $campaign['browser_lang_rule'] = $_POST['browser_lang_rule'];
            $campaign['show_in_posts'] = $_POST['show_in_posts'] ?? '';
            $campaign['show_in_pages'] = $_POST['show_in_pages'] ?? '';
            $campaign['show_at_homepage'] = $_POST['show_at_homepage'] ?? '';
            $campaign['show_in_categoris'] = $_POST['show_in_categoris'] ?? '';
            $campaign['show_in_tags'] = $_POST['show_in_tags'] ?? '';
            $campaign['show_in_archives'] = $_POST['show_in_archives'] ?? '';
            $campaign['show_in_search_results'] = $_POST['show_in_search_results'] ?? '';
            $campaign['show_in_excerpts'] = $_POST['show_in_excerpts'] ?? '';
            $campaign['start_html_element'] = $_POST['start_html_element'];
            $campaign['end_html_element'] = $_POST['end_html_element'];
            $campaign['use_regex'] = $_POST['use_regex'] ?? '';

            if (WPAI_PRO) {
                $campaign['city_codes'] = trim($_POST['city_codes']);
                $campaign['city_code_rule'] = $_POST['city_code_rule'];
                $campaign['show_on_monday'] = $_POST['show_on_monday'] ?? '';
                $campaign['show_on_tuesday'] = $_POST['show_on_tuesday'] ?? '';
                $campaign['show_on_wednesday'] = $_POST['show_on_wednesday'] ?? '';
                $campaign['show_on_thursday'] = $_POST['show_on_thursday'] ?? '';
                $campaign['show_on_friday'] = $_POST['show_on_friday'] ?? '';
                $campaign['show_on_saturday'] = $_POST['show_on_saturday'] ?? '';
                $campaign['show_on_sunday'] = $_POST['show_on_sunday'] ?? '';
                $campaign['time_ranges'] = trim($_POST['time_ranges']);
            }

            if (isset($_POST['modify-campaign'])) {
                if (isset($_POST['index'])) {
                    if (isset($this->cm->campaigns[intval($_POST['index'])])) {
                        $this->cm->campaigns[intval($_POST['index'])] = $campaign;
                        $this->cm->save();
                    }
                } else {
                    $this->cm->campaigns[] = $campaign;
                    $this->cm->save();
                }
            }
        }

        if (get_option(WPMI_MESSAGE)) {
            echo '<div id="message" class="notice notice-warning"><p>' . get_option(WPMI_MESSAGE) . '</p></div>';
            delete_option(WPMI_MESSAGE);
        }
        echo '<div class="wrap">';
        if (isset($_GET['new-campaign'])) {
            $this->cm->new_campaign_menu();
        } elseif (isset($_GET['edit-campaign']) && wp_verify_nonce($_GET['_wpnonce'] ?? '', 'wpai-campaign-edit')) {
            $this->cm->edit_campaign_menu(intval($_GET['edit-campaign']));
        } else {
            $this->cm->display_campaigns();
        }
        echo '</div>';
    }

    public function dashboard_menu() {
        if (isset($_POST['save-options']) && check_admin_referer('wpai')) {
            $this->options['delete_on_uninstall'] = $_POST['delete_on_uninstall'] ?? '';
            $this->options['geoip_auto_update'] = $_POST['geoip_auto_update'] ?? '';
            $this->options['geoip_last_update'] = $_POST['geoip_last_update'] ?? time();
            update_option(WPAI_OPTIONS, $this->options);
        }
        ?>

        <div class="wrap">
            <img style="width: 100%;" src="<?php echo $this->plugin_dir_url; ?>/images/wpadinserter.png" />
            <div style="text-align: right;">WP Ad Inserter <?php
                if (WPAI_PRO) {
                    echo 'Pro ';
                }
                ?>version <?php echo get_option(WPAI_VERSION); ?></div>
            <h2 style="margin: 34pt 0 8pt 0;">Dashboard</h2>
            <form id="wpai_options" method="post">
                <table style="width:90%" class="form-table">
                    <?php
                    echo '<tr>';
                    echo '<th>Autoupdate GeoIP database</th>';
                    echo '<td>';
                    echo '<input name="geoip_auto_update" type="checkbox" ' . ((($this->options['geoip_auto_update']) === 'on') ? 'checked ' : '') . '">';
                    echo '<span style="color: #646970;"> - when enabled, the GeoIP gatabase will be automatically updated once a week.</span>';
                    echo '</td>';
                    echo '</tr>';
                    echo '<tr>';
                    echo '<th>Delete plugin data on uninstall</th>';
                    echo '<td>';
                    echo '<input name="delete_on_uninstall" type="checkbox" ' . ((($this->options['delete_on_uninstall']) === 'on') ? 'checked ' : '') . '">';
                    echo '<span style="color: #646970;"> - delete all the WP Ad Inserter data on plugin uninstall.</span>';
                    echo '</td>';
                    echo '</tr>';
                    echo '<tr>';
                    echo '</tr>';
                    $ip = wpai_get_the_user_ip();
                    if ($ip && is_object($this->maxmind_geoip2)) {
                        $ipData = $this->maxmind_geoip2->get($ip);
                        echo '<th>Self info</th>';
                        echo '<td>';
                        echo 'IP: <strong>' . $ip . '</strong><br />';
                        if (isset($ipData['country']['iso_code'])) {
                            echo 'Country ISO code: <strong>' . $ipData['country']['iso_code'] . '</strong><br />';
                        }
                        if (isset($ipData['city']['names']['en'])) {
                            echo 'City: <strong>' . $ipData['city']['names']['en'] . '</strong><br />';
                        }
                        if (isset($ipData['location']['time_zone'])) {
                            echo 'Time zone: <strong>' . $ipData['location']['time_zone'] . '</strong><br />';
                        }
                        echo 'Browser languages: <strong>' . implode(', ', wpai_get_browser_langs()) . '</strong><br />';
                        echo '</td>';
                        echo '</tr>';
                    }
                    echo '<th>Resources</th>';
                    echo '<td>';
                    echo '<a href="https://www.wpadinserter.com/" target="_blank">Website</a> | <a href="https://www.wpadinserter.com/campaign-settings/" target="_blank">Documentation</a>';
                    echo '</td>';
                    echo '</tr>';
                    wp_nonce_field('wpai');
                    ?>
                </table>
                <input class = "button-primary" style="margin-top: 16pt;" name="save-options" value=" Save " type="submit">
            </form>    
        </div>
        <?php
    }

    public function maxmind_geoip2_base_update($base_url, $base_file) {
        if (!function_exists('gzopen')) {
            return;
        }
        $upload_dir = wp_upload_dir();
        if (!is_writable($upload_dir['path'])) {
            return;
        }
        $response = wp_remote_get($base_url, array(
            'timeout' => 60,
            'sslverify' => false
        ));
        if (is_wp_error($response) || wp_remote_retrieve_response_code($response) !== 200) {
            return false;
        }
        $temp = download_url($base_url);
        if (is_wp_error($temp)) {
            return;
        }
        if (!$zh = gzopen($temp, 'rb')) {
            unlink($temp);
            return;
        }
        if (!$fh = fopen($this->plugin_dir_path . $base_file, 'wb')) {
            unlink($temp);
            return;
        }
        while (($data = gzread($zh, 4096)) != false) {
            fwrite($fh, $data);
        }
        gzclose($zh);
        fclose($fh);
        unlink($temp);
    }

    protected function get_geoip_base() {
        return $this->plugin_dir_path . '/inc/geoip2/GeoLite2-Country.mmdb';
    }

    protected function is_country_found($campaign, $ip) {
        if ($ip && is_object($this->maxmind_geoip2)) {
            $ipData = $this->maxmind_geoip2->get($ip);
            if (!$ipData || !isset($ipData['country']['iso_code'])) {
                return;
            }
            $found = false;
            foreach (explode(',', $campaign['country_codes']) as $country_code) {
                if (strtolower(trim($country_code)) === strtolower(trim($ipData['country']['iso_code']))) {
                    $found = true;
                    break;
                }
            }
            return $found;
        }
        return false;
    }

    public function prepare_ad($campaign, $count = true, $spot_name = '') {
        global $post;

        $ads = explode('<!--more-->', $campaign['ad_code']);
        if (count($ads)) {
            if (isset($post->ID)) {
                if ($campaign['rotate'] !== 'on') {
                    mt_srand(intval($post->ID));
                } else {
                    mt_srand(time());
                }

                // filter by post IDs
                if (strlen(trim($campaign['post_ids']))) {
                    $found = false;
                    foreach (explode(',', $campaign['post_ids']) as $id) {
                        if ($id == $post->ID) {
                            $found = true;
                            break;
                        }
                    }
                    if (($found && $campaign['post_ids_rule'] === 'hide') || (!$found && $campaign['post_ids_rule'] === 'show')) {
                        return;
                    }
                }

                // filter by categories
                $post_cats = array_map('strtolower', (wp_get_post_categories($post->ID, array('fields' => 'names'))));
                if (strlen(trim($campaign['cats']))) {
                    $total = 0;
                    $found = 0;
                    foreach (explode(',', $campaign['cats']) as $cat) {
                        if (in_array(mb_strtolower(trim($cat)), $post_cats)) {
                            $found++;
                        }
                        $total++;
                    }
                    if (!wpai_check_rule(($campaign['cat_rule']), $found, $total)) {
                        return;
                    }
                }

                // filter by tags
                $post_tags = array_map('strtolower', $post->tags_input);
                if (strlen(trim($campaign['tags']))) {
                    $total = 0;
                    $found = 0;
                    foreach (explode(',', $campaign['tags']) as $tag) {
                        if (in_array(mb_strtolower(trim($tag)), $post_tags)) {
                            $found++;
                        }
                        $total++;
                    }
                    if (!wpai_check_rule(($campaign['tag_rule']), $found, $total)) {
                        return;
                    }
                }

                // filter by keywords
                $content = '';
                if ($campaign['target_content'] === 'on') {
                    $content .= ' ' . $post->post_content;
                }
                if ($campaign['target_excerpt'] === 'on') {
                    $content .= ' ' . $post->post_excerpt;
                }
                if ($campaign['target_title'] === 'on') {
                    $content .= ' ' . $post->post_title . ' ';
                }
                if (strlen(trim($campaign['keywords']))) {
                    $total = 0;
                    $found = 0;
                    foreach (explode(',', $campaign['keywords']) as $keyword) {
                        if (preg_match('/\b' . preg_quote(trim($keyword)) . '\b/isu', $content)) {
                            $found++;
                        }
                        $total++;
                    }
                    if (!wpai_check_rule(($campaign['keyword_rule']), $found, $total)) {
                        return;
                    }
                }

                // filter by devices
                if (!isset($this->aimd)) {
                    $this->aimd = new Mobile_Detect();
                }
                $found = false;
                if ($campaign['device_computer'] === 'on') {
                    if (!$this->aimd->isMobile()) {
                        $found = true;
                    }
                }
                if ($campaign['device_tablet'] === 'on') {
                    if ($this->aimd->isTablet()) {
                        $found = true;
                    }
                }
                if ($campaign['device_phone'] === 'on') {
                    if ($this->aimd->isMobile() && !$this->aimd->isTablet()) {
                        $found = true;
                    }
                }
                if (($found && $campaign['devices_rule'] === 'hide') || (!$found && $campaign['devices_rule'] === 'show')) {
                    return;
                }

                // Prepare for GeoIP checks 
                $ip = wpai_get_the_user_ip();

                // filter countries by GeoIP
                if (strlen(trim($campaign['country_codes']))) {
                    $found = $this->is_country_found($campaign, $ip);
                    if (($found && $campaign['country_code_rule'] === 'hide') || (!$found && $campaign['country_code_rule'] === 'show')) {
                        return;
                    }
                }

                // filter cities by GeoIP (Pro)
                if (WPAI_PRO && strlen(trim($campaign['city_codes']))) {
                    $found = $this->is_city_found($campaign, $ip);
                    if (($found && $campaign['city_code_rule'] === 'hide') || (!$found && $campaign['city_code_rule'] === 'show')) {
                        return;
                    }
                }

                // filter weekdays by GeoIP (Pro)
                if (WPAI_PRO) {
                    if (!$this->check_week_day($campaign, $ip)) {
                        return;
                    }
                }

                // filter time ranges by GeoIP (Pro)
                if (WPAI_PRO) {
                    if (!$this->check_time_range($campaign, $ip)) {
                        return;
                    }
                }

                // filter by browser languages
                if (strlen(trim($campaign['browser_langs']))) {
                    $browser_langs = wpai_get_browser_langs();
                    if (!count($browser_langs)) {
                        return;
                    }
                    $found = false;
                    foreach (explode(',', $campaign['browser_langs']) as $lang) {
                        if (in_array(strtolower(trim($lang)), array_map('strtolower', $browser_langs))) {
                            $found = true;
                            break;
                        }
                    }
                    if (($found && $campaign['browser_lang_rule'] === 'hide') || (!$found && $campaign['browser_lang_rule'] === 'show')) {
                        return;
                    }
                }
            }
            if ($campaign['php_exec'] === 'on') {
                ob_start();
                try {
                    eval(' ?>' . stripcslashes($ads[mt_rand(0, count($ads) - 1)]) . '<?php ');
                    $result = ob_get_contents();
                } catch (\Throwable $e) {
                    $result = '<p><code>PHP error: ' . $e->getMessage() . '. Please check the ad code in the WP Ad Inserter campaign ID ' . $campaign['id'] . ' ("' . $campaign['name'] . '").</code></p>';
                }
                ob_end_clean();
            } else {
                $result = stripcslashes($ads[mt_rand(0, count($ads) - 1)]);
            }
            // return the ad code
            if ($count) {
                $this->cm->inc_total_impressions($campaign['id']);
                $this->spots->inc_spots($spot_name);
            }
            return $result;
        }
        return;
    }

    public function campaign_by_id(int $id) {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['id'] === $id) {
                return $campaign;
            }
        }
        return null;
    }

    function shortcode($atts) {
        if ($this->campaign_by_id(intval($atts['id']))) {
            return $this->prepare_ad($this->campaign_by_id(intval($atts['id'])), true, 'shortcode');
        }
    }

    public function init() {
        if (isset($_GET['delete-campaign']) && wp_verify_nonce($_GET['_wpnonce'] ?? '', 'wpai-campaign-delete')) {
            $this->cm->delete_compaign(intval($_GET['delete-campaign']));
            header('Location: ?page=wpai');
            die();
        } elseif (isset($_GET['up']) && wp_verify_nonce($_GET['_wpnonce'] ?? '', 'wpai-campaign-up')) {
            $this->cm->move_compaign_up(intval($_GET['up']));
            header('Location: ?page=wpai');
            die();
        } elseif (isset($_GET['down']) && wp_verify_nonce($_GET['_wpnonce'] ?? '', 'wpai-campaign-down')) {
            $this->cm->move_compaign_down(intval($_GET['down']));
            header('Location: ?page=wpai');
            die();
        }
    }
    
    public function version_control() {
        $plugin_data = get_plugin_data($this->plugin_dir_path . '/wpadinserter.php');
        $version = $plugin_data['Version'];
        update_option(WPAI_VERSION, $version);

        if (get_option(WPAI_ACTION)) {
            if (get_option(WPAI_ACTION) === 'ACTIVATE') {
                wp_remote_get('https://www.wpadinserter.com/rest/stat.php?site=' . urlencode(site_url()) . '&ver=' . $version . '&action=ACTIVATION');
            } elseif (get_option(WPAI_ACTION) === 'UPGRADE') {
                wp_remote_get('https://www.wpadinserter.com/rest/stat.php?site=' . urlencode(site_url()) . '&ver=' . $version . '&action=UPGRADE');
            }
            delete_option(WPAI_ACTION);
            // reset geoip_last_update to update or download GeoIP base for the 1st time on activation or upgrade
            $this->options['geoip_last_update'] = 0;
            update_option(WPAI_OPTIONS, $this->options);
        }
    }

    public function admin_init() {
        $this->version_control();
        if (!file_exists($this->plugin_dir_path . '/inc/geoip2/GeoLite2-Country.mmdb') || ($this->options['geoip_auto_update'] === 'on' && (time() - $this->options['geoip_last_update']) > 604800)) {
            $this->maxmind_geoip2_base_update(WPAI_MIXMIND_GEOIP2_COUNTRY_BASE_URL, '/inc/geoip2/GeoLite2-Country.mmdb');
            $this->options['geoip_last_update'] = time();
            update_option(WPAI_OPTIONS, $this->options);
        }
    }

    public function to_show($campaign) {
        if (($campaign['show_at_homepage'] !== 'on' && is_home()) || ($campaign['show_in_categoris'] !== 'on' && is_category()) || ($campaign['show_in_tags'] !== 'on' && is_tag()) ||
                ($campaign['show_in_archives'] !== 'on' && is_archive()) || ($campaign['show_in_search_results'] !== 'on' && is_search()) ||
                ($campaign['show_in_posts'] !== 'on' && is_single()) || ($campaign['show_in_pages'] !== 'on' && is_page())) {
            return false;
        }
        return true;
    }

    public function wpai_content($content, $campaign, $count = true) {
        if (!$this->to_show($campaign)) {
            return $content;
        }
        switch ($campaign['position']) {
            case 'before-content':
                if ($this->spots->is_available('before-content', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = $this->prepare_ad($campaign, $count, 'before-content') . $content;
                }
                break;
            case 'after-content':
                if ($this->spots->is_available('after-content', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content .= $this->prepare_ad($campaign, $count, 'after-content');
                }
                break;
            case 'before-paragraph':
                if ($this->spots->is_available('before-paragraph', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_html_element_ad($content, '/(<p.*?>)/is', $this->prepare_ad($campaign, $count, 'before-paragraph'), $campaign['bp_pos'], true);
                }
                break;
            case 'after-paragraph':
                if ($this->spots->is_available('after-paragraph', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_html_element_ad($content, '/(<\/p>)/is', $this->prepare_ad($campaign, $count, 'after-paragraph'), $campaign['ap_pos'], false);
                }
                break;
            case 'before-heading':
                if ($this->spots->is_available('before-heading', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_html_element_ad($content, '/(<' . $campaign['bh_tag'] . '.*?>)/is', $this->prepare_ad($campaign, $count, 'before-heading'), $campaign['bh_pos'], true);
                }
                break;
            case 'after-heading':
                if ($this->spots->is_available('after-heading', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_html_element_ad($content, '/(<\/' . $campaign['ah_tag'] . '.*?>)/is', $this->prepare_ad($campaign, $count, 'after-heading'), $campaign['ah_pos'], false);
                }
                break;
            case 'before-image':
                if ($this->spots->is_available('before-image', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_html_element_ad($content, '/(<img .*?>)/is', $this->prepare_ad($campaign, $count, 'before-image'), $campaign['bi_pos'], true);
                }
                break;
            case 'after-image':
                if ($this->spots->is_available('after-image', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_html_element_ad($content, '/(<img .*?>)/is', $this->prepare_ad($campaign, $count, 'after-image'), $campaign['ai_pos'], false);
                }
                break;
            case 'between-html':
                if ($this->spots->is_available('between-html', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    $content = wpai_replace_text_between($campaign['start_html_element'], $campaign['end_html_element'], $this->prepare_ad($campaign, $count, 'between-html'), $content, ($campaign['use_regex'] === 'on'));
                }
                break;
        }
        return $content;
    }

    public function the_content($content) {
        foreach ($this->cm->campaigns as $campaign) {
            $content = $this->wpai_content($content, $campaign);
        }
        return $content;
    }

    public function the_excerpt($content) {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['show_in_excerpts'] === 'on') {
                $content = $this->wpai_content($content, $campaign);
            }
        }
        return $content;
    }

    public function the_post($post) {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'before-post') {
                if (($campaign['show_at_homepage'] === 'on' && is_home()) ||
                        ($campaign['show_in_pages'] === 'on' && is_page()) ||
                        ($campaign['show_in_categoris'] === 'on' && is_category()) ||
                        ($campaign['show_in_tags'] === 'on' && is_tag()) ||
                        ($campaign['show_in_archives'] === 'on' && is_archive()) ||
                        ($campaign['show_in_archives'] === 'on' && is_archive())) {
                    static $pos = 1;
                    if ($pos++ === $campaign['bfp_pos']) {
                        if ($this->spots->is_available('bfp_pos', $campaign['behavior'], $campaign['max_ad_limit'])) {
                            echo $this->prepare_ad($campaign, true, 'bfp_pos');
                        }
                    }
                }
            }
        }
    }

    public function loop_start($query) {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'before-the-loop') {
                if ($this->spots->is_available('before-the-loop', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'before-the-loop');
                }
            }
        }
        return $query;
    }

    public function loop_end($query) {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'after-the-loop') {
                if ($this->spots->is_available('after-the-loop', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'after-the-loop');
                }
            }
        }
        return $query;
    }

    public function comment_form_before() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'comment-form-before') {
                if ($this->spots->is_available('comment-form-before', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'comment-form-before');
                }
            }
        }
    }

    public function comment_form_after() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'comment-form-after') {
                if ($this->spots->is_available('comment-form-after', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'comment-form-after');
                }
            }
        }
    }

    public function comment_form_top() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'comment-form-top') {
                if ($this->spots->is_available('comment-form-top', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'comment-form-top');
                }
            }
        }
    }

    public function comment_form_before_fields() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'comment-form-before-fields') {
                if ($this->spots->is_available('comment-form-before-fields', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'comment-form-before-fields');
                }
            }
        }
    }

    public function comment_form_after_fields() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'comment-form-after-fields') {
                if ($this->spots->is_available('comment-form-after-fields', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'comment-form-after-fields');
                }
            }
        }
    }

    public function wp_footer() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($campaign['position'] === 'site-footer') {
                if ($this->spots->is_available('site-footer', $campaign['behavior'], $campaign['max_ad_limit'])) {
                    echo $this->prepare_ad($campaign, true, 'site-footer');
                }
            }
        }
    }

    public function wp_head() {
        foreach ($this->cm->campaigns as $campaign) {
            if ($this->to_show($campaign)) {
                echo $campaign['ad_head'];
                return;
            }
        }
    }

    public function activation() {
        update_option(WPAI_ACTION, 'ACTIVATE');
    }

    public function settings_menu() {
        add_menu_page(__('WP Ad Inserter', 'wpai-menu'), __('WP Ad Inserter', 'wpai-menu'), 'manage_options', 'wpai-home', array($this, 'dashboard_menu'), 'dashicons-megaphone');
        add_submenu_page('wpai-home', __('Dashboard', 'wpai-menu'), __('Dashboard', 'wpai-menu'), 'manage_options', 'wpai-home', array($this, 'dashboard_menu'));
        add_submenu_page('wpai-home', __('Ad campaigns', 'wpai-menu'), __('Ad campaigns', 'wpai-menu'), 'manage_options', 'wpai', array($this, 'wpai_menu'));
    }

}
?>