<?php

namespace WPAI;

function wpai_in_ranges($value, $str) {
    if (!strlen(trim($str))) {
        return true;
    }
    $ranges = explode(',', trim($str));
    foreach ($ranges as $range) {
        $limits = explode('-', $range);
        if (count($limits) === 1) {
            if (intval($limits[0]) === intval($value)) {
                return true;
            }
        } elseif (count($limits) === 2) {
            if (intval($value) >= abs(intval($limits[0])) && intval($value) <= abs(intval($limits[1]))) {
                return true;
            }
        }
    }
    return false;
}

function wpai_get_the_user_ip() {
    if (!empty($_SERVER['HTTP_CLIENT_IP']) && filter_var($_SERVER['HTTP_CLIENT_IP'], FILTER_VALIDATE_IP)) {
        $ip = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR']) && filter_var($_SERVER['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP)) {
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } else {
        $ip = $_SERVER['REMOTE_ADDR'];
    }

    // get an external IP for a local host
    if ($ip === '127.0.0.1') {
        $response = wp_remote_get("http://ipecho.net/plain", array(
        'timeout' => 60,
        'sslverify' => false,
        'user-agent' => 'Mozilla/5.0 (Windows NT 10.0; WOW64; rv:97.0) Gecko/20100101 Firefox/97.0/3871tuT2p1u-81'    
        ));
        if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
            $ip = $response['body'];
        }
    }

    return filter_var($ip, FILTER_VALIDATE_IP);
}

function wpai_replace_text_between($start, $end, $replacement, $str, $regex = false, $limit = -1) {
    $replacement = $start . $replacement . $end;
    if ($regex) {
        $start = str_replace('\'', '\\\'', $start);
        $end = str_replace('\'', '\\\'', $end);
    } else {
        $start = preg_quote($start, '/');
        $end = preg_quote($end, '/');
    }
    return preg_replace("/({$start})(.*?)({$end})/", $replacement, $str, $limit);
}

function wpai_check_rule(string $rule, int $found, int $total) {
    switch (strtolower($rule)) {
        case 'any':
            return ($found > 0);
        case 'none':
            return ($found === 0);
        case 'all':
            return ($found === $total);
    }
    return null;
}

function wpai_get_browser_langs() {
    $langs = [];
    if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
        preg_match_all('/([a-z]{1,8}(-[a-z]{1,8})?)\s*(;\s*q\s*=\s*(1|0\.[0-9]+))?/i', $_SERVER['HTTP_ACCEPT_LANGUAGE'], $matches);
        if (count($matches[1])) {
            $langs = $matches[1];
            arsort($langs, SORT_NUMERIC);
        }
    }
    return $langs;
}

function wpai_html_element_ad($content, $pattern, $ad, $pos = 1, $before = true) {
    if ($pos < 0) {
        $pos = 1 + $pos + preg_match_all($pattern, $content);
    } elseif ($pos === 0) {
        $pos = rand(1, preg_match_all($pattern, $content));
    }
    $content = preg_replace_callback($pattern,
            function ($m) use ($pos, $ad, $before) {
                static $i = 1;
                if ($i++ === $pos ?? 1) {
                    if ($before) {
                        return $ad . $m[0];
                    } else {
                        return $m[0] . $ad;
                    }
                } else {
                    return $m[0];
                }
            }, $content);
    return $content;
}

?>