<?php

/**
 * Plugin Name: WP Ad Inserter
 * Plugin URI: https://www.wpadinserter.com/
 * Description: A compact and powerful ad manager plugin for WordPress.
 * Version: 1.1.7
 * Author: CyberSEO
 * Author URI: https://www.cyberseo.net/
 * Requires at least: 5.0
 * Tested up to: 6.0.1
 * Requires PHP: 7.1
 * 
 */

namespace WPAI;

if (!defined('ABSPATH')) {
    die('Invalid request.');
}

define('WPAI_CAMPAIGNS', 'wpai_campaigns');
define('WPAI_OPTIONS', 'wpai_options');
define('WPAI_ACTION', 'wpai_action');
define('WPAI_VERSION', 'wpai_version');
define('WPMI_MESSAGE', 'wpai_message');

if (!class_exists('\MaxMind\Db\Reader')) {
    require_once plugin_dir_path(__FILE__) . 'inc/maxmind-db-reader/src/MaxMind/Db/Reader.php';
    require_once plugin_dir_path(__FILE__) . 'inc/maxmind-db-reader/src/MaxMind/Db/Reader/Decoder.php';
    require_once plugin_dir_path(__FILE__) . 'inc/maxmind-db-reader/src/MaxMind/Db/Reader/InvalidDatabaseException.php';
    require_once plugin_dir_path(__FILE__) . 'inc/maxmind-db-reader/src/MaxMind/Db/Reader/Metadata.php';
    require_once plugin_dir_path(__FILE__) . 'inc/maxmind-db-reader/src/MaxMind/Db/Reader/Util.php';
}

require_once plugin_dir_path(__FILE__) . 'inc/mobiledetect/Mobile_Detect.php';

require_once plugin_dir_path(__FILE__) . 'inc/functions.php';
require_once plugin_dir_path(__FILE__) . 'classes/class-wpai-widget.php';
require_once plugin_dir_path(__FILE__) . 'classes/class-wpai-ad-spots.php';

if (file_exists(plugin_dir_path(__FILE__) . 'classes/class-wpai-pro.php')) {
    define('WPAI_PRO', true);
    require_once plugin_dir_path(__FILE__) . 'classes/class-wpai.php';
    require_once plugin_dir_path(__FILE__) . 'classes/class-wpai-pro.php';
    $wpai = new WPAI_Pro(plugin_dir_url(__FILE__), DIRNAME(__FILE__));
} else {
    define('WPAI_PRO', false);
    require_once plugin_dir_path(__FILE__) . 'classes/class-wpai.php';
    $wpai = new WPAI(plugin_dir_url(__FILE__), DIRNAME(__FILE__));
}

function wpai_add_scripts() {
    wp_enqueue_style('wpai', plugins_url('css/wpai.css', __FILE__), array(), filemtime(plugin_dir_path(__FILE__) . 'css/wpai.css'));
    wp_enqueue_script('wpai', plugins_url('js/wpai.js', __FILE__));
    wp_enqueue_style('codemirror', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/codemirror.min.css');
    wp_enqueue_script('codemirror', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/codemirror.min.js');
    wp_enqueue_script('xml', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/mode/xml/xml.min.js');
    wp_enqueue_script('javascript', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/mode/javascript/javascript.min.js');
    wp_enqueue_script('css', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/mode/css/css.min.js');
    wp_enqueue_script('clike', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/mode/clike/clike.min.js');
    wp_enqueue_script('php', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/mode/php/php.min.js');
}

function wpai_uninstall() {
    global $wpai;
    wp_remote_get('https://www.wpadinserter.com/rest/stat.php?site=' . urlencode(site_url()) . '&ver=' . get_option(WPAI_VERSION) . '&action=UNINSTALL');
    if ($wpai->options['delete_on_uninstall'] === 'on') {
        delete_option(WPAI_OPTIONS);
        delete_option(WPAI_CAMPAIGNS);
        delete_option(WPAI_ACTION);
        delete_option(WPAI_VERSION);
        delete_option(WPAI_MESSAGE);
    }
}

if (is_admin()) {
    require_once 'inc/plugin-update-checker/plugin-update-checker.php';
    $wpai_UpdateChecker = \Puc_v4_Factory::buildUpdateChecker('https://www.wpadinserter.com/updates/info.php', __FILE__, 'wpadinserter');

    add_action('init', array($wpai, 'init'));
    add_action('admin_init', array($wpai, 'admin_init'));
    add_action('admin_enqueue_scripts', __NAMESPACE__ . '\wpai_add_scripts');

    register_uninstall_hook(__FILE__, __NAMESPACE__ . '\wpai_uninstall');
    register_activation_hook(__FILE__, array($wpai, 'activation'));
} else {
    add_shortcode('wpadinserter', array($wpai, 'shortcode'));

    add_filter('wp_head', array($wpai, 'wp_head'));
    add_filter('the_post', array($wpai, 'the_post'));
    add_filter('the_content', array($wpai, 'the_content'));
    add_filter('the_excerpt', array($wpai, 'the_excerpt'));
    add_filter('loop_start', array($wpai, 'loop_start'));
    add_filter('loop_end', array($wpai, 'loop_end'));
    add_filter('comment_form_before', array($wpai, 'comment_form_before'));
    add_filter('comment_form_after', array($wpai, 'comment_form_after'));
    add_filter('comment_form_top', array($wpai, 'comment_form_top'));
    add_filter('comment_form_after_fields', array($wpai, 'comment_form_after_fields'));
    add_filter('comment_form_before_fields', array($wpai, 'comment_form_before_fields'));
    add_filter('wp_footer', array($wpai, 'wp_footer'));
}

add_action('upgrader_process_complete', function ($upgrader_object, $options) {
    if (isset($options['plugins']) && in_array('wpadinserter/wpadinserter.php', $options['plugins'])) {
        $plugin_data = get_plugin_data(plugin_dir_path(__FILE__) . 'wpadinserter.php');
        $version = $plugin_data['Version'];
        update_option(WPAI_ACTION, 'UPGRADE');
        wp_remote_get('https://www.wpadinserter.com/rest/stat.php?site=' . urlencode(site_url()) . '&ver=' . $version . '&action=UPGRADE');
    }
}, 10, 2);
?>